@@ -2,7 +2,7 @@
 from line_profiler import LineProfiler
 from functools import wraps
 import numpy as np
-#import torch
+import torch
 import pysnooper
 
 
@@ -68,14 +68,14 @@ class Debugger(object):
                       'TIME': func_line_time}
         self.DEBUG_MODE = DEBUG_MODE
         self._mode = 'TIME'
-        
-    def __call__(self, func):
-        @wraps(func)
-        def selector():
-            wrapper = self.DEBUG_MODE[self._mode]
+    
+    @property
+    def __call__(self):
+        def selector(func):
             def w(*arg, **kw):
-                wrapper(func(*arg, **kw))
-                func_return = func(*arg, **kw)
+                wrapper = self.DEBUG_MODE[self._mode]
+                func_wrapper = wrapper(func)
+                func_return = func_wrapper(*arg, **kw)
                 return func_return
             return w
         return selector
